==> 0.0.13.tar.gz: lib/FirebaseSevice.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'common.dart';
import 'methods.dart';

class FirebaseSevice {
  static final lstCommonCollection = ['Account', 'Language'];
  static CollectionReference getCollection(String collectionName) {
    if (lstCommonCollection.contains(collectionName)) {
      return FirebaseFirestore.instance.collection(collectionName);
    }
    return FirebaseFirestore.instance
        .collection(Common.mainCollection)
        .doc(Common.mainDocument)
        .collection(collectionName);
  }

  static Query getQuery(String collectionName,
      {Map<String, Object> conditions,
      Map<String, bool> orderBy,
      int limit = -1}) {
    if (limit == null) {
      limit = -1;
    }

    Query collection = FirebaseSevice.getCollection(collectionName);
    try {
      if (conditions != null && conditions.length > 0) {
        conditions.forEach((key, value) {
          collection = collection.where(key, isEqualTo: value);
        });
      }

      if (orderBy != null && orderBy.length > 0) {
        orderBy.forEach((key, value) {
          collection = collection.orderBy(key, descending: value);
        });
      }
      if (limit > 0) {
        collection = collection.limit(limit);
      }
    } catch (e) {
      print('getCollection : ' + e.toString());
    }

    return collection;
  }

  static int getNewDocumentID() {
    DateTime  dt = (FieldValue.serverTimestamp() as Timestamp).toDate();
    String documentId = dt
        .difference(DateTime.utc(2000, 1, 1))
        .inSeconds
        .toString();
    return Methods.stringToInt(documentId);
  }

  static Map getNewDataTemplate(Map<String, Object> dict, int uid) {
    dict["documentID"] = getNewDocumentID();
    dict["uid"] = uid;
    dict["statusData"] = 1;
    dict["createDate"] = FieldValue.serverTimestamp();

    return dict;
  }

  static Map getModified(Map<String, Object> dict, int uid) {
    dict["modifiedUid"] = uid;
    dict["modifiedDate"] = FieldValue.serverTimestamp();
    return dict;
  }

  static Future setData(
      Map<String, Object> data, String colllectionPath, int uid) async {
    bool isNew;
    if (data.containsKey('documentID')) {
      isNew = false;
      data = getModified(data, uid);
    } else {
      isNew = true;
      data = getNewDataTemplate(data, uid);
    }
    int documentID = Methods.stringToInt(data['documentID'].toString());
    if (isNew) {
      getCollection(colllectionPath)
          .doc(documentID.toString())
          .set(data, SetOptions(merge: true));
    } else {
      getCollection(colllectionPath).doc(documentID.toString()).update(data);
    }
  }
}

==> 0.0.14.tar.gz: lib/FirebaseSevice.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'common.dart';
import 'methods.dart';

class FirebaseSevice {
  static final lstCommonCollection = ['Account', 'Language'];
  static CollectionReference getCollection(String collectionName) {
    if (lstCommonCollection.contains(collectionName)) {
      return FirebaseFirestore.instance.collection(collectionName);
    }
    return FirebaseFirestore.instance
        .collection(Common.mainCollection)
        .doc(Common.mainDocument)
        .collection(collectionName);
  }

  static Query getQuery(String collectionName,
      {Map<String, Object> conditions,
      Map<String, bool> orderBy,
      int limit = -1}) {
    if (limit == null) {
      limit = -1;
    }

    Query collection = FirebaseSevice.getCollection(collectionName);
    try {
      if (conditions != null && conditions.length > 0) {
        conditions.forEach((key, value) {
          collection = collection.where(key, isEqualTo: value);
        });
      }

      if (orderBy != null && orderBy.length > 0) {
        orderBy.forEach((key, value) {
          collection = collection.orderBy(key, descending: value);
        });
      }
      if (limit > 0) {
        collection = collection.limit(limit);
      }
    } catch (e) {
      print('getCollection : ' + e.toString());
    }

    return collection;
  }

  static int getNewDocumentID() {
    DateTime  dt = DateTime.now();
    String documentId = dt
        .difference(DateTime.utc(2000, 1, 1))
        .inSeconds
        .toString();
    return Methods.stringToInt(documentId);
  }

  static Map getNewDataTemplate(Map<String, Object> dict, int uid) {
    dict["documentID"] = getNewDocumentID();
    dict["uid"] = uid;
    dict["statusData"] = 1;
    dict["createDate"] = FieldValue.serverTimestamp();

    return dict;
  }

  static Map getModified(Map<String, Object> dict, int uid) {
    dict["modifiedUid"] = uid;
    dict["modifiedDate"] = FieldValue.serverTimestamp();
    return dict;
  }

  static Future setData(
      Map<String, Object> data, String colllectionPath, int uid) async {
    bool isNew;
    if (data.containsKey('documentID')) {
      isNew = false;
      data = getModified(data, uid);
    } else {
      isNew = true;
      data = getNewDataTemplate(data, uid);
    }
    int documentID = Methods.stringToInt(data['documentID'].toString());
    if (isNew) {
      getCollection(colllectionPath)
          .doc(documentID.toString())
          .set(data, SetOptions(merge: true));
    } else {
      getCollection(colllectionPath).doc(documentID.toString()).update(data);
    }
  }
}
